<?php
/*
Plugin Name: Giraffe theme support
Plugin URI: http://www.urbangiraffe.com/plugins/giraffe
Description: Support functions for the Giraffe theme.  Go to the <a href="options-general.php?page=giraffe/giraffe.php">Options/Giraffe</a> menu to configure the theme.
Author: John Godley
Author URI: http://www.urbangiraffe.com
Version: 1.23
*/


if (!defined ('GIRAFFE_VERSION'))
  include (ABSPATH."/wp-content/themes/giraffe/giraffe_functions.php");

$giraffe_news     = true;
$giraffe_old_news = 60 * 60 * 24 * 7;
$giraffe_news_url = 'http://www.urbangiraffe.com/giraffenews.php?version='.GIRAFFE_VERSION;

giraffe_initialize ();

if (is_plugin_page())
  giraffe_options ();
else
{
  function giraffe_get_select ($name, $val)
  {
    if (get_option ($val) == $name)
      echo ' selected="selected"';
  }

  function giraffe_checked ($name, $def = false)
  {
    $opt = get_option ($name);
    if ($opt == "true" || ($opt === false && $def == true))
      echo ' checked="checked"';
  }

  function giraffe_get_news ()
  {
    global $giraffe_news, $giraffe_old_news;
    if ($giraffe_news == false)
      return;

    // Only check for news if we are running on PHP version >= 4.3.0
    $version = explode ('.', phpversion ());
    if ($version[0] >= 4 && $version[1] >= 0 && $version[2] >= 0)
    {
      $new = false;

      // If 'news.html' is over X days old then download latest news and overwrite
      $last = get_option ('giraffe_news_last');
      if ($last === false || $last > time () + $giraffe_old_news || $last == 0)
      {
        global $giraffe_news_url;
        if (($contents = @file_get_contents ($giraffe_news_url)) !== false && $contents)
        {
          update_option ('giraffe_news_last', time ());
          update_option ('giraffe_news', $contents);
        }
      }

      $contents = get_option ("giraffe_news");
      if ($contents)
      {
        ?>
          <fieldset class="options">
            <legend><?php _ge ('News')?></legend>
            <?php echo $contents ?>
          </fieldset>
       <?php
      }
    }
  }

  function giraffe_options ()
  {
    // Get list of logos
    $logolist[] = "None";
    $logolist[] = "Random";
    $logolist[] = "Custom";
    $ldir = @opendir (dirname (__FILE__).'/../../themes/giraffe/logo/');
    while ($ldir && ($file = readdir ($ldir)) !== false)
    {
      $ext = substr (strrchr ($file, "."), 1);
      if ($ext == "jpg" || $ext == "png" || $ext == "gif")
        $logolist[] = $file;
    }

    if ($ldir)
      closedir ($ldir);

    // Display error message?
    if (isset ($_GET['error']))
    {
      echo '<div style="background-color: red; width:80%; margin: 0 auto; padding: 5px">Problem updating files - is the theme directory write-enabled?</div>';
    }
    ?>
  	<form action="<?php echo $_SERVER['PHP_SELF'] ?>" method="post">
    <div class="wrap">
      <h2><?php _ge('Giraffe theme support')?></h2>
      <?php giraffe_get_news () ?>
  	  <fieldset class="options">
  	    <legend><?php _ge('Appearance')?></legend>
  	    <table>
  	      <tr><td><?php _ge('Colour scheme:')?></td><td>
  	    <select name="scheme">
  	      <option value="blue"<?php giraffe_get_select ('blue', 'giraffe_scheme') ?>><?php _ge('Blue')?></option>
  	      <option value="red"<?php giraffe_get_select ('red', 'giraffe_scheme') ?>><?php _ge('Red')?></option>
  	      <option value="green"<?php giraffe_get_select ('green', 'giraffe_scheme') ?>><?php _ge('Green')?></option>
  	      <option value="brown"<?php giraffe_get_select ('brown', 'giraffe_scheme') ?>><?php _ge('Brown')?></option>
  	      <option value="grey"<?php giraffe_get_select ('grey', 'giraffe_scheme') ?>><?php _ge('Grey')?></option>
  	    </select></td></tr>
        <tr><td><?php _ge ('Enable curved corners:') ?></td><td><input type="checkbox" name="curves"<?php giraffe_checked ('giraffe_curves')?>/> <?php _ge ('and left bar:')?> <input type="checkbox" name="leftbar"<?php giraffe_checked ('giraffe_leftbar')?>/></td></tr>
  	    <tr><td><?php _ge('Font:')?></td><td>
  	    <select name="font">
  	      <option value="font1"<?php giraffe_get_select ('font1', 'giraffe_font') ?>>Tahoma</option>
  	      <option value="font2"<?php giraffe_get_select ('font2', 'giraffe_font') ?>>Verdana</option>
  	      <option value="font3"<?php giraffe_get_select ('font3', 'giraffe_font') ?>>Arial</option>
  	    </select> <?php _ge('set to')?>
  	    <select name="size_lead">
  	      <option value="large"<?php giraffe_get_select ('large', 'giraffe_fontsize_lead') ?>><?php _ge('Large')?></option>
  	      <option value="small"<?php giraffe_get_select ('small', 'giraffe_fontsize_lead') ?>><?php _ge('Small')?></option>
  	    </select> <?php _ge('for lead posts')?>
        </td></tr>
  	    <tr>
  	      <td><?php _ge ('Logo') ?>:</td>
  	      <td><select name="logo">
    	       <?php foreach ($logolist AS $logo)
    	             {
    	                echo '<option value="'.$logo.'"';
    	                giraffe_get_select ($logo, 'giraffe_logo');
    	                echo '>'.$logo.'</option>';
    	             }
    	       ?>
  	      </select> <?php _ge ('at position') ?>:
  	      <select name="logopos">
  	        <option value="left"<?php giraffe_get_select ('left', 'giraffe_logo_pos') ?>><?php _ge ('Left') ?></option>
  	        <option value="center"<?php giraffe_get_select ('center', 'giraffe_logo_pos') ?>><?php _ge ('Centre') ?></option>
  	        <option value="right"<?php giraffe_get_select ('right', 'giraffe_logo_pos') ?>><?php _ge ('Right')?></option>
  	      </select> <em><?php _ge (' (logos are stored in the \'giraffe/logo\' directory)'); ?></em>
  	      </td>
  	    </tr>
  	    <tr><td valign="top"><?php _ge('Layout:')?></td><td>
  	    <table>
  	      <tr>
  	        <td><img src="../wp-content/plugins/giraffe/layout1.png" alt="layout1"/></td>
  	        <td><img src="../wp-content/plugins/giraffe/layout2.png" alt="layout2"/></td>
  	      </tr>
  	      <tr>
  	        <?php $layouts = array ('full', 'traditional');
  	              for ($x = 0; $x < 2; $x++)
  	              {?>
  	                <td align="center"><input type="radio" name="bloglayout" value="<?php echo $layouts[$x]; ?>"<?php if (get_option ('giraffe_layout') == $layouts[$x]) echo ' checked="checked"'; ?>/></td>
  	        <?php } ?>
  	      </tr>
  	    </table>
  	    </td></tr>
      </table>
      </fieldset>
      <fieldset class="options">
        <legend><?php _ge('Page dimensions')?></legend>
        <img style="float: left; margin-left: 30px" src="../wp-content/plugins/giraffe/layoutsize.png" alt="layout2"/>
        <table style="margin-top: 25px">
  	    <tr><td><?php _ge('Page width:')?></td><td>
    	    <select name="width_page">
            <option value="fluid"<?php giraffe_get_select ('fluid', 'giraffe_width_page') ?>><?php _ge ('Fluid') ?></option>
            <option value="1024"<?php giraffe_get_select ('1024', 'giraffe_width_page') ?>>1024 pixels</option>
            <option value="800"<?php giraffe_get_select ('800', 'giraffe_width_page') ?>>800 pixels</option>
          </select>
        </td></tr>
  	    <tr><td><?php _ge('Blog width:')?></td><td>
  	      <select name="width_blog">
            <option value="100"<?php giraffe_get_select ('100', 'giraffe_width_blog') ?>>100%</option>
            <option value="90"<?php giraffe_get_select ('90', 'giraffe_width_blog') ?>>90%</option>
            <option value="85"<?php giraffe_get_select ('85', 'giraffe_width_blog') ?>>85%</option>
            <option value="75"<?php giraffe_get_select ('75', 'giraffe_width_blog') ?>>75%</option>
            <option value="65"<?php giraffe_get_select ('65', 'giraffe_width_blog') ?>>65%</option>
          </select>
        </td></tr>
  	    <tr><td><?php _ge('Sidebar width:')?></td><td>
  	      <select name="width_sidebar">
            <option value="10"<?php giraffe_get_select ('10', 'giraffe_width_sidebar') ?>>10%</option>
            <option value="15"<?php giraffe_get_select ('15', 'giraffe_width_sidebar') ?>>15%</option>
            <option value="20"<?php giraffe_get_select ('20', 'giraffe_width_sidebar') ?>>20%</option>
            <option value="25"<?php giraffe_get_select ('25', 'giraffe_width_sidebar') ?>>25%</option>
            <option value="30"<?php giraffe_get_select ('30', 'giraffe_width_sidebar') ?>>30%</option>
          </select></td></tr>
  	    </table>
      </fieldset>
      <fieldset class="options">
        <legend><?php _ge('Post options')?></legend>
        <img style="float: left; margin-left: 30px" src="../wp-content/plugins/giraffe/layoutposts.png" alt="layout2"/>
        <table>
          <tr><td><?php _ge('Number of lead posts')?></td><td><input type="text" size="3" name="posts_lead" value="<?php echo get_option ('giraffe_posts_lead') ?>"/></td></tr>
          <tr><td><?php _ge('Number of recent posts')?></td><td><input type="text" size="3" name="posts_other" value="<?php echo get_option ('giraffe_posts_other') ?>"/> <em>(<?php _ge ('only show excerpt')?> <input type="checkbox" name="posts_other_excerpt"<?php giraffe_checked ('giraffe_posts_other_excerpt')?>/>)</em></td></tr>
          <tr><td><?php _ge('Number of random posts')?></td><td><input type="text" size="3" name="posts_random" value="<?php echo get_option ('giraffe_posts_random') ?>"/> <em>(<?php _ge ('displayed on single post page') ?>)</em></td></tr>
        </table>
      </fieldset>
      <fieldset class="options">
        <legend><?php _ge ('Comments')?></legend>
        <img style="float: left; margin-left: 30px" src="../wp-content/plugins/giraffe/layoutcomments.png" alt="layout2"/>
        <table>
          <tr><td><?php _ge('Number of recent comments:')?></td><td><input type="text" size="3" name="comments_recent" value="<?php echo get_option ('giraffe_comments') ?>"/> <em>(<?php _ge ('displayed on front page')?>)</em></td>
          <tr><td><?php _ge ('Comment order:')?></td>
              <td>
                <select name="comments_order">
                  <option value="asc"<?php giraffe_get_select ('asc', 'giraffe_comments_order') ?>><?php _ge ('Oldest first')?></option>
                  <option value="desc"<?php giraffe_get_select ('desc', 'giraffe_comments_order') ?>><?php _ge ('Newest first')?></option>
                </select>
              </td>
          </tr>
          <tr><td><?php _ge ('Enable Gravatars:')?></td><td><input type="checkbox" name="comments_gravatar"<?php giraffe_checked ('giraffe_comments_gravatar', true)?>/></td></tr>
        </table>
      </fieldset>
      <fieldset class="options">
        <legend><?php _ge ('Sidebar')?></legend>
        <img style="float: left; margin-left: 30px" src="../wp-content/plugins/giraffe/layoutsidebar.png" alt="layout2"/>
        <table style="margin-top: 20px">
          <tr><td><?php _ge ('Enable calendar:') ?></td><td><input type="checkbox" name="calendar"<?php giraffe_checked ('giraffe_calendar')?>/> + <label for="ajax"><a href="http://www.urbangiraffe.com/plugins/ajax-calendar">AJAX</a></label> <input type="checkbox" name="ajax" id="ajax"<?php giraffe_checked ('giraffe_ajax') ?>/></td></tr>
          <tr><td><?php _ge ('Enable localization menu:') ?></td><td><input type="checkbox" name="localization"<?php giraffe_checked ('giraffe_localization')?>/></td></tr>
          <tr><td><a href="<?php echo get_option('siteurl').'/wp-admin/theme-editor.php?file=wp-content/themes/giraffe/sidebar-extra.php&amp;theme=Giraffe'?>"><?php _ge ('Edit sidebar') ?></a></td><td></td></tr>
        </table>
      </fieldset>
      <fieldset class="options">
        <legend><?php _ge ('Other')?></legend>
        <table>
          <tr><td><label for="url_icon"><?php _ge('Show icon for external links:')?></label></td><td><input type="checkbox" name="url_icon" id="url_icon"<?php giraffe_checked ('giraffe_urlicon')?>/></td></tr>
          <tr><td><?php _ge('Author text:')?></td><td><input type="text" name="authortext" value="<?php echo get_option ('giraffe_author')?>"/></td></tr>
          <tr><td><label for="compress"><?php _ge ('Compress CSS (not using gzip):'); ?></label></td><td><input type="checkbox" id="compress" name="compress"<?php giraffe_checked ('giraffe_csscompress') ?>/></td></tr>
        </table>
      </fieldset>
      <p class="submit">
        <input type="submit" name="Submit" value="<?php _ge('Update Options')?> &raquo;" />
        <input type="hidden" name="giraffe" value="giraffe"/>
      </p>
    </div>
    </form>
    <?php
  }

  $giraffe_header = "";
  function reggy ($matches)
  {
    global $giraffe_header;
    if (strpos ($matches[0], "Theme Name: Giraffe"))
      $giraffe_header = $matches[0];
    return "";
  }

  function giraffe_submit ()
  {
    $scheme              = $_POST['scheme'];
    $font                = $_POST['font'];
    $size_lead           = $_POST['size_lead'];
    $posts_lead          = intval ($_POST['posts_lead']);
    $posts_other         = intval ($_POST['posts_other']);
    $posts_random        = intval ($_POST['posts_random']);
    $comments            = intval ($_POST['comments_recent']);
    $comments_order      = $_POST['comments_order'];
    $comments_shrink     = false;
    $comments_gravatar   = false;
    $calendar            = false;
    $localization        = false;
    $url_icon            = false;
    $posts_other_excerpt = false;
    $logo                = $_POST['logo'];
    $logopos             = $_POST['logopos'];
    $width_page          = $_POST['width_page'];
    $width_blog          = $_POST['width_blog'];
    $width_sidebar       = $_POST['width_sidebar'];
    $author              = $_POST['authortext'];
    $layout              = $_POST['bloglayout'];
    $topmenu             = $_POST['topmenu'];
    $compress            = false;
    $curves              = false;
    $leftbar             = false;
    $ajax                = false;

    if ($layout == "")
      $layout = "full";
    if (isset ($_POST['comments_shrink']))
      $comments_shrink = true;
    if (isset ($_POST['comments_gravatar']))
      $comments_gravatar = true;
    if (isset ($_POST['compress']))
      $compress = true;
    if (isset ($_POST['url_icon']))
      $url_icon = true;
    if (isset ($_POST['calendar']))
      $calendar = true;
    if (isset ($_POST['localization']))
      $localization = true;
    if (isset ($_POST['leftbar']))
      $leftbar = true;
    if (isset ($_POST['curves']))
      $curves = true;
    if (isset ($_POST['posts_other_excerpt']))
      $posts_other_excerpt = true;
    if (isset ($_POST['ajax']))
      $ajax = true;

    update_option ('giraffe_scheme',             $scheme);
    update_option ('giraffe_font',               $font);
    update_option ('giraffe_fontsize_lead',      $size_lead);
    update_option ('giraffe_posts_lead',         $posts_lead);
    update_option ('giraffe_posts_other',        $posts_other);
    update_option ('giraffe_posts_random',       $posts_random);
    update_option ('giraffe_comments',           $comments);
    update_option ('giraffe_urlicon',            $url_icon ? "true" : "false");
    update_option ('giraffe_width_page',         mysql_real_escape_string ($width_page));
    update_option ('giraffe_width_blog',         mysql_real_escape_string ($width_blog));
    update_option ('giraffe_width_sidebar',      mysql_real_escape_string ($width_sidebar));
    update_option ('giraffe_author',             mysql_real_escape_string ($author));
    update_option ('giraffe_layout',             $layout);
    update_option ('giraffe_logo',               $logo);
    update_option ('giraffe_logo_pos',           $logopos);
    update_option ('giraffe_csscompress',        $compress ? "true" : "false");
    update_option ('giraffe_comments_order',     $comments_order);
    update_option ('giraffe_comments_shrink',    $comments_shrink ? "true" : "false");
    update_option ('giraffe_comments_gravatar',  $comments_gravatar ? "true" : "false");
    update_option ('giraffe_localization',       $localization ? "true" : "false");
    update_option ('giraffe_calendar',           $calendar ? "true" : "false");
    update_option ('giraffe_curves',             $curves ? "true" : "false");
    update_option ('giraffe_leftbar',            $leftbar ? "true" : "false");
    update_option ('giraffe_posts_other_excerpt',$posts_other_excerpt ? "true" : "false");
    update_option ('giraffe_ajax',               $ajax ? "true" : "false");

    // Refresh the theme
    if (($style = file_get_contents (dirname (__FILE__).'/style.css')) !== false)
    {
    	$location = get_option('siteurl') . '/wp-admin/admin.php?page=giraffe/giraffe.php';

      // Update the variables
      $host = "http://".$_SERVER['SERVER_NAME'];

      $fonts = array (
                       'font1' => "Tahoma, 'Trebuchet MS', Arial, Verdana, Sans-Serif",
                       'font2' => "Verdana, Sans-serif",
                       'font3' => "Arial"
                     );
      $colours = array
      (
        "blue" => array (
                          '$pageborder'    => '#5b5a61',
                          '$lightbar'      => '#b8d2da',
                          '$midbar'        => '#aac8d0',
                          '$darkbar'       => '#8db8c3',
                          '$fontcolour'    => '#2f3b4f',
                          '$subfontcolour' => '#6c64a8',
                          '$brightlink'    => 'red',
                          '$link'          => '#13076b',
                          '$quote'         => '#f0f0f0',
                          '$sidebarback'   => '#dbe6e9',
                          '$pagenav'       => '#5a7095',
                        ),
        "red"  => array (
                          '$pageborder'    => '#952825',
                          '$lightbar'      => '#eaaba9',
                          '$midbar'        => '#e59896',
                          '$darkbar'       => '#dc7774',
                          '$fontcolour'    => '#5b1917',
                          '$subfontcolour' => '#de7e7b',
                          '$brightlink'    => 'green',
                          '$link'          => '#5b1917',
                          '$quote'         => '#f9e7e7',
                          '$sidebarback'   => '#f3d2d1',
                          '$pagenav'       => '#bf3430',
                        ),
        "green" => array (
                          '$pageborder'    => '#538139',
                          '$lightbar'      => '#c3deb4',
                          '$midbar'        => '#b7d7a4',
                          '$darkbar'       => '#9fca87',
                          '$fontcolour'    => '#395827',
                          '$subfontcolour' => '#79b557',
                          '$brightlink'    => 'red',
                          '$link'          => '#334f23',
                          '$quote'         => '#eff6eb',
                          '$sidebarback'   => '#dfedd7',
                          '$pagenav'       => '#6ba549',
                        ),
        "brown" => array (
                          '$pageborder'    => '#7c5f26',
                          '$lightbar'      => '#dabe85',
                          '$midbar'        => '#d5b576',
                          '$darkbar'       => '#cca659',
                          '$fontcolour'    => '#54411a',
                          '$subfontcolour' => '#a87b24',
                          '$brightlink'    => 'red',
                          '$link'          => '#54411a',
                          '$quote'         => '#e9d9b9',
                          '$sidebarback'   => '#e4d0a7',
                          '$pagenav'       => '#9f7a31',
                        ),
        "grey" => array (
                          '$pageborder'    => '#5b5a61',
                          '$lightbar'      => '#c9c9c9',
                          '$midbar'        => '#bdbdbd',
                          '$darkbar'       => '#a8a8a8',
                          '$fontcolour'    => '#4c4c4c',
                          '$subfontcolour' => '#959595',
                          '$brightlink'    => 'red',
                          '$link'          => '#4c4c4c',
                          '$quote'         => '#f0f0f0',
                          '$sidebarback'   => '#e2e2e2',
                          '$pagenav'       => '#777777',
                        ),
      );

      // Logo options
      $ielogo  = "";
      $logocss = "";
      if ($logo != "Custom" && $logo != "None" && $logo != "Random")
      {
        $logocss = "background: transparent url(logo/$logo) no-repeat $logopos top;";
        if (substr ($logo, -3, 3) == 'png')
        {
          $parts = explode ('.', $logo);
          if (file_exists (dirname (__FILE__)."/../../themes/giraffe/logo/".$parts[0].".gif"))
           $ielogo = "* html body #headerimg \n{\nbackground: transparent url(logo/".$parts[0].".gif) no-repeat $logopos top; }";
        }
      }

      // Calculate widths
      if ($width_page == "fluid")
        $blog_width_page = $width_blog."%";
      else
        $blog_width_page = (($width_page / 100) * $width_blog)."px";

      $other = array
               (
                '$fontfamily' => $fonts[$font],
                '$fontlead'   => $size_lead == 'large' ? "1.2em" : "1em",
                '$urlicon'    => '.entry p a[href ^="http://"], .entrytext p a[href ^="http://"], .commentlist p a[href ^="http://"], .entrytext ul a[href ^="http://"], .entry ul a[href ^="http://"]
{
  background: url($scheme/external.png) center right no-repeat;
  padding-right: 13px;
}

.entry a[href ^="'.$host.'"], .entrytext a[href ^="'.$host.'"], .commentlist p a[href ^="'.$host.'"]
{
background: none !important;
padding-right: 0 !important;
}',
                '$pagewidth'  => $blog_width_page,
                '$leftwidth'  => (98 - $width_sidebar)."%",
                '$rightwidth' => $width_sidebar."%",
                '$logo'       => $logocss,
                '$ielogo'     => $ielogo,
                '$scheme'     => $scheme,
                '$sidebartop' => $layout == "full" ? "0" : "4em"
               );

      if ($width_blog == "100" && $width_page == "fluid")
      {
        $style = str_replace ('$blogpageborder',  '', $style);
        $style = str_replace ('$leftblogpage',    '', $style);
        $style = str_replace ('$rightblogpage',   '', $style);
      }
      else
      {
        $style = str_replace ('$blogpageborder',  'border: 1px solid $pageborder;', $style);
        $style = str_replace ('$leftblogpage',    'border-left: 1px solid $pageborder;', $style);
        $style = str_replace ('$rightblogpage',   'border-right: 1px solid $pageborder;', $style);
      }

      if ($leftbar)
      {
        $style = str_replace ('$leftbar',        'background: white url($scheme/column.gif) repeat-y top left;', $style);
        $style = str_replace ('$leftfootbar',    'background: transparent url($scheme/column.gif) repeat-y 20px 0px;', $style);
        $style = str_replace ('$leftcontentbar', 'padding-left: 3em;', $style);
        $style = str_replace ('$linkbarbottom',  ".linkbarbottom\n{\nbackground: ".'$darkbar url($scheme/column-diff.gif) repeat-y 20px 0px; height: 1.1em; padding-bottom: 4px; }', $style);
        $style = str_replace ('$footerp',        '60px', $style);
      }
      else
      {
        $style = str_replace ('$leftbar',        '', $style);
        $style = str_replace ('$leftfootbar',    '', $style);
        $style = str_replace ('$linkbarbottom',  '.linkbarbottom { height: 1.1em }', $style);
        $style = str_replace ('$leftcontentbar', '', $style);
        $style = str_replace ('$footerp',        '20px', $style);
      }

      $corners = array ('$1corner' => 'background: $lightbar url($scheme/blue-top-corner.gif) no-repeat top left;',
                        '$2corner' => 'background: $sidebarback url($scheme/sidebar-bottom-corner.gif) no-repeat bottom left;',
                        '$3corner' => 'background: $darkbar url($scheme/sidebar-top-corner.gif) no-repeat top left;');

      $cornersempty = array ('$1corner' => 'background-color: $lightbar;',
                             '$2corner' => 'background-color: $sidebarback;',
                             '$3corner' => 'background-color: $darkbar;');

      foreach ($corners AS $key => $corner)
      {
        if ($curves)
          $style = str_replace ($key, $corner, $style);
        else
          $style = str_replace ($key, $cornersempty[$key], $style);
      }

      foreach ($colours[$scheme] AS $replace => $colour)
        $style = str_replace ($replace, $colour, $style);

      foreach ($other AS $replace => $value)
        $style = str_replace ($replace, $value, $style);

      if (($target = @fopen (dirname (__FILE__).'/../../themes/giraffe/style.css', 'w')))
      {
        // Do regex stuff
        if ($compress)
        {
          $style = preg_replace_callback ("/\/\*(.*?)\*\//s", "reggy", $style);
          $style = str_replace ("\n", "", $style);
          $style = str_replace ("\r", "", $style);
          $style = str_replace (": ", ":", $style);
          $style = str_replace ("  ", " ", $style);
          $style = str_replace ("{ ", "", $style);
          $style = str_replace (", ", ",", $style);

          global $giraffe_header;
          $style = $giraffe_header.$style;
        }

        // Write
        fwrite ($target, $style);
        fclose ($target);

        // Now copy the correct layouts
        $layouts = array ("index.php", "single.php", "page.php");
        foreach ($layouts AS $layfile)
        {
          @copy (dirname (__FILE__)."/".$layout."/$layfile", dirname (__FILE__)."/../../themes/giraffe/$layfile");
        }
      }
      else
      {
        header('Location: '.$location."&error=true");
        return;
      }
    }

  	header('Location: '.$location);
  }

  // Function to add InScript into the options page
  function giraffe_add_options_page()
  {
    if (function_exists('add_options_page'))
  	  add_options_page('Giraffe Theme', 'Giraffe Theme', 5, 'giraffe/giraffe.php');
  }

  add_action('admin_head', 'giraffe_add_options_page');

  if (isset ($_POST['giraffe']))
    giraffe_submit ();
}

?>